@@ -195,7 +195,27 @@ class S3ToSqs(
         :summary: Constructs a new instance of the S3ToSqs class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(S3ToSqs.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
+                s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = S3ToSqsProps(
@@ -316,7 +336,25 @@ class S3ToSqsProps:
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if __debug__:
-            type_hints = typing.get_type_hints(S3ToSqsProps.__init__)
+            def stub(
+                *,
+                bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+                logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+                log_s3_access_logs: typing.Optional[builtins.bool] = None,
+                max_receive_count: typing.Optional[jsii.Number] = None,
+                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+                s3_event_filters: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.NotificationKeyFilter, typing.Dict[str, typing.Any]]]] = None,
+                s3_event_types: typing.Optional[typing.Sequence[aws_cdk.aws_s3.EventType]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
             check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
             check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
